==> spreadsheets-8.x-1.3.tar.gz: spreadsheets/src/SpreadSheets.php <==
<?php

namespace Drupal\spreadsheets;

use Google_Client;
use Google_Service_Sheets;
use Drupal\file\Entity\File;

/**
 * Class for the service  javali_sheets.base .
 *
 * This service enables the creation,  * configuration and data
 * retrieval of a google sheet.
 *
 * @author kallado
 */
class SpreadSheets {

  private $client;
  private $sheetId;
  private $range;
  private $sheetName;

  /**
   * JavaliSheets constructor.
   */
  public function __construct() {
    $config = \Drupal::config('spreadsheets.google_sheets_config');
    $this->client = $this->getClient();
    $this->sheet_id = $config->get('sheet_id');
    $this->range = $config->get('range');
    $this->sheetName = $config->get('sheet_name');
  }

  /**
   * Function to get the Google client.
   *
   * @return \Google_Client
   *   the Google client
   *
   * @throws Exception
   */
  public function getClient() {
    $config = \Drupal::config('spreadsheets.spreadsheetscredentials');

    $fid = $config->get('credentials_file')[0];
    $file = File::load($fid);
    $credentials_path = \Drupal::service('file_system')->realpath('private://' . $file->getFilename());
    $client = new Google_Client();
    $client->setApplicationName('Google Sheets API PHP Quickstart');
    $client->setScopes(Google_Service_Sheets::SPREADSHEETS_READONLY);
    $client->setAuthConfig($credentials_path);
    $client->setAccessType('offline');

    $tokenPath = \Drupal::service('file_system')->realpath('private://token.json');
    // Load previously authorized credentials from a file.
    if (file_exists($tokenPath)) {
      $accessToken = json_decode(file_get_contents($tokenPath), TRUE);
      $client->setAccessToken($accessToken);
    }
    else {
      $messenger = \Drupal::messenger();
      $messenger->addError("The file " . $tokenPath . " doesn't exist");
      return $client;
    }

    // Refresh the token if it's expired.
    if ($client->isAccessTokenExpired()) {
      $client->fetchAccessTokenWithRefreshToken($client->getRefreshToken());
      file_put_contents($tokenPath, json_encode($client->getAccessToken()));
    }
    return $client;
  }

  /**
   * Get the API client and construct the service object.
   *
   * @return array
   *   an array with the sheet data
   */
  public function getdata() {
    $client = $this->client;
    $service = new Google_Service_Sheets($client);
    $spreadsheetId = $this->sheet_id;
    $name = $this->sheetName;
    $range = $this->range;
    $messenger = \Drupal::messenger();

    try {
      $sheetInfo = $service->spreadsheets->get($spreadsheetId);
    }
    catch (\Google_Service_Exception $e) {
      $error = json_decode($e->getMessage(), TRUE);
      return $messenger->addMessage($error['error']['message'], 'error');
    }

    $allsheet_info = $sheetInfo['sheets'];
    $idCats = array_column($allsheet_info, 'properties');

    // Checks if the sheet exists.
    if (!$this->myArrayContainsWord($idCats, $name)) {
      return $messenger->addMessage('Sheet not found', 'error');
    }

    $range_format = $name . '!' . $range;

    try {
      $response = $service->spreadsheets_values->get($spreadsheetId, $range_format);
      return $response;
    }
    catch (\Google_Service_Exception $e) {
      $error = json_decode($e->getMessage(), TRUE);
      return $messenger->addMessage($error['error']['message'], 'error');
    }

  }

  /**
   * Set the sheet id.
   *
   * @param string $id
   *   The google sheet id.
   */
  public function setSheetId(string $id) {
    $this->sheet_id = $id;
  }

  /**
   * Set the string range.
   *
   * @param string $range
   *   range (format ex A1:B2)
   */
  public function setRange(string $range) {
    $this->range = $range;
  }

  /**
   * Set the sheet name.
   *
   * @param string $name
   *   The name of the shee (ex:Sheet1)
   */
  public function setSheetName(string $name) {
    $this->sheetName = $name;
  }

  /**
   * Checks if myArray contains a word as key.
   *
   * @param array $myArray
   *   The array to check.
   * @param mixed $word
   *   The word to find.
   *
   * @return bool
   *   True if the word is found false otherwise
   */
  public function myArrayContainsWord(array $myArray, $word) {
    foreach ($myArray as $element) {
      if ($element->title == $word) {
        return TRUE;
      }
    }
    return FALSE;
  }

}

==> spreadsheets-8.x-1.33.tar.gz: spreadsheets/src/SpreadSheets.php <==
<?php

namespace Drupal\spreadsheets;

use Google_Client;
use Google_Service_Sheets;
use Drupal\file\Entity\File;
use Google_Service_Drive;

/**
 * Class for the service  javali_sheets.base .
 *
 * This service enables the creation,  * configuration and data
 * retrieval of a google sheet.
 *
 * @author kallado
 */
class SpreadSheets {

  /**
   * The Google_Client object.
   *
   * @var Google_Client
   */
  private $client;

  /**
   * The sheet id from config.
   *
   * @var string
   */
  private $sheetId;

  /**
   * The range from config.
   *
   * @var string
   */
  private $range;

  /**
   * The sheet name from config.
   *
   * @var string
   */
  private $sheetName;

  /**
   * JavaliSheets constructor.
   */
  public function __construct() {
    $config = \Drupal::config('spreadsheets.google_sheets_config');
    $this->client = $this->getClient();
    $this->sheet_id = $config->get('sheet_id');
    $this->range = $config->get('range');
    $this->sheetName = $config->get('sheet_name');
  }

  /**
   * Function to get the Google client.
   *
   * @return \Google_Client
   *   the Google client
   *
   * @throws Exception
   */
  public function getClient() {
    $config = \Drupal::config('spreadsheets.spreadsheetscredentials');

    $fid = $config->get('credentials_file')[0];
    $file = File::load($fid);
    $credentials_path = \Drupal::service('file_system')->realpath('private://' . $file->getFilename());
    $client = new Google_Client();
    $client->setApplicationName('Google Sheets API PHP Quickstart');
    $client->setScopes([
      Google_Service_Drive::DRIVE,
      Google_Service_Sheets::SPREADSHEETS
    ]);
    $client->setAuthConfig($credentials_path);
    $client->setAccessType('offline');
    $client->setApprovalPrompt('force');

    $tokenPath = \Drupal::service('file_system')->realpath('private://token.json');
    // Load previously authorized credentials from a file.
    if (file_exists($tokenPath)) {
      $accessToken = json_decode(file_get_contents($tokenPath), TRUE);
      $client->setAccessToken($accessToken);
    }
    else {
      $messenger = \Drupal::messenger();
      $messenger->addError("The file " . $tokenPath . " doesn't exist");
      return $client;
    }

    // Refresh the token if it's expired.
    if ($client->isAccessTokenExpired()) {
      $client->fetchAccessTokenWithRefreshToken($client->getRefreshToken());
      file_put_contents($tokenPath, json_encode($client->getAccessToken()));
    }
    return $client;
  }

  /**
   * Get the API client and construct the service object.
   *
   * @return array
   *   an array with the sheet data
   */
  public function getdata() {
    $client = $this->client;
    $service = new \Google_Service_Sheets($client);
    $spreadsheetId = $this->sheet_id;
    $name = $this->sheetName;
    $range = $this->range;
    $messenger = \Drupal::messenger();

    try {
      $sheetInfo = $service->spreadsheets->get($spreadsheetId);
    }
    catch (\Google_Service_Exception $e) {
      $error = json_decode($e->getMessage(), TRUE);
      return $messenger->addMessage($error['error']['message'], 'error');
    }

    $allsheet_info = $sheetInfo['sheets'];
    $idCats = array_column($allsheet_info, 'properties');

    // Checks if the sheet exists.
    if (!$this->myArrayContainsWord($idCats, $name)) {
      return $messenger->addMessage('Sheet not found', 'error');
    }

    $range_format = $name . '!' . $range;

    try {
      $response = $service->spreadsheets_values->get($spreadsheetId, $range_format);
      return $response;
    }
    catch (\Google_Service_Exception $e) {
      $error = json_decode($e->getMessage(), TRUE);
      return $messenger->addMessage($error['error']['message'], 'error');
    }

  }

  /**
   * Set the sheet id.
   *
   * @param string $id
   *   The google sheet id.
   */
  public function setSheetId(string $id) {
    $this->sheet_id = $id;
  }

  /**
   * Set the string range.
   *
   * @param string $range
   *   range (format ex A1:B2)
   */
  public function setRange(string $range) {
    $this->range = $range;
  }

  /**
   * Set the sheet name.
   *
   * @param string $name
   *   The name of the shee (ex:Sheet1)
   */
  public function setSheetName(string $name) {
    $this->sheetName = $name;
  }

  /**
   * Checks if myArray contains a word as key.
   *
   * @param array $myArray
   *   The array to check.
   * @param mixed $word
   *   The word to find.
   *
   * @return bool
   *   True if the word is found false otherwise
   */
  public function myArrayContainsWord(array $myArray, $word) {
    foreach ($myArray as $element) {
      if ($element->title == $word) {
        return TRUE;
      }
    }
    return FALSE;
  }

}
